<?php


class Spai_Widget
{
    CONST RELATED_POSTS_DEFAULT_HEADING = 'Related posts:';
    CONST RELATED_POSTS_DEFAULT_IMAGE = __SPAI_PUBLIC__ . 'img/default-picture.png';
    private $post_id = null;
    private $my_plugin_options = null;
    private $token;
    private $count_posts = 0;
    private $max_ads_count = 0;

    public $content = null;

    public function __construct( $token = null, $my_plugin_options ) {
        $this->token = $token;
        $this->post_id = get_the_ID();
        $this->my_plugin_options = $my_plugin_options;

        $this->setCountPosts();
        $this->setMaxAdsCount();

        $postsData = $this->getRelatedPosts();
        $relatedPosts = $postsData['posts'];
        $ads = $postsData['ads'];
        $ads = array_chunk($ads, $this->max_ads_count)[0]; //ограничиваем массив макс допустимым количеством рекламы

        if( $postsData !== false and !empty( $relatedPosts ) ) {
            $send_impression = $this->sendImpression( $relatedPosts );

			$imp_id = null;
			if( !empty( $send_impression ) and $send_impression->result === true) {
				$imp_id = (int) $send_impression->data->imp_id;
			}

            $data = $this->prepareDataToWidget( $relatedPosts, $ads );

            $related_posts_as_html = $this->widgetAsHtml( $data, $imp_id );

            $this->content = $related_posts_as_html;
        }
    }

    private function getRelatedPosts()
    {
        $api = new Spai_Api( $this->token );

        $answer = $api->getRelatedPosts( $this->post_id, $this->count_posts );
        //echo '<pre>';var_dump($answer);exit;
        if( is_wp_error( $answer ) ) {
            return false;
        }
        $json =  json_decode( json_decode( $answer['body'] ) );
        if( $json->result == true ) {
            $relatedPosts = $json->data->posts;
            $ads = $json->data->ads;
            return [
                'posts' => $relatedPosts,
                'ads' => $ads
            ];
        } else {
            return false;
        }
    }

    private function widgetAsHtml( $data, $imp_id )
    {
        $html = '';
        $display_type = ( $this->my_plugin_options['display_type'] ) ? (int)$this->my_plugin_options['display_type'] : 1;

        $main_additional_classes = [];
        $main_additional_classes[] = 'spai-dt' . $display_type;
        $main_additional_classes[] = ((bool)$this->my_plugin_options['show_category'] === true) ? 'with_cat' : '';

        if( $data ) {

            $html .= '<div class="spai-widget_content '.implode(' ', $main_additional_classes).'">';
            $html .= $this->setHeadingHtml();
            $html .= '<div class="spai-widget-posts" for_post_id="' . $this->post_id . '" imp_id="' . $imp_id . '">';
            foreach ($data as $item ) {
                if ($item->type === 'ads') {
                    $extIdHtml = '';
                } else {
                    $extIdHtml = ' related_post_id="' . $item->external_id . '"';
                }
                $html .= '<div class="spai-one_related_post" '.$extIdHtml.'>';
                    $html .= $this->setUrlHtml(
                        $item->url,
                        $this->setImgHtml( $item->img ),
                        $item->type
                    );

                    $html .= $this->setUrlHtml(
                        $item->url,
                        $this->setTitleHtml( $item->title ),
                        $item->type
                    );

                    if ($item->type === 'post') {
                        $html .= $this->setCategoriesHtml($item->categories);
                    } else {
                        $html .= $this->setAdsNotifierHtml();
                    }

                $html .= '</div>';

            }
            $html .= '</div>';
            $html .= '</div>';
        }
        return $html;
    }

    private function setCategoriesHtml($categories) {
        $html = '';
        if(count($categories) > 0) {
            $html .= '<div class="spai-categories">';
            $category_links_html = [];
            foreach ($categories as $category) {
                $category_link = get_category_link( $category->external_id );
                $category_links_html[] = '<a class="spai-one_category" href="' . esc_url( $category_link ) . '">'.$category->name.'</a>';
            }
            $html .= implode(' ', $category_links_html);
            $html .= '</div>';
        }
        return $html;
    }

    private function setHeadingHtml()
    {
        $heading = ( $this->my_plugin_options['heading'] ) ? esc_attr( $this->my_plugin_options['heading'] ) : self::RELATED_POSTS_DEFAULT_HEADING;

        return '<h3 class="spai-widget-header">' . $heading . '</h3>';
    }

    private function setTitle( $title )
    {
        $title_max = ( $this->my_plugin_options['title_max'] ) ? (int)$this->my_plugin_options['title_max'] : 50;

        $title_to_show = ( mb_strlen( $title, 'UTF-8' ) > $title_max ) ?
            mb_strimwidth( $title, 0, $title_max, "...", 'UTF-8' ) :
            $title;
        return esc_html( $title_to_show );
    }

    private function setTitleHtml( $title )
    {
        $title = $this->setTitle( $title );

        return '<div class="spai-related_post_title">' . $title . '</div>';
    }

    private function setUrlHtml( $url, $urlHtml, $type )
    {
        $html = '';
        $rel = '';

        if ($type == 'ads') {
            $html .= '<noindex>';
            $rel = 'rel="sponsored nofollow"';
        }

        $html .= '<a href="' . esc_url( $url ) . '" '.$rel.'>';
            $html .= $urlHtml;
        $html .= '</a>';

        if ($type == 'ads') {
            $html .= '</noindex>';
        }
        return $html;
    }

    private function setImgUrl( $img_url )
    {
        return $img_url ?
            esc_url( $img_url ) :
            (
            $this->my_plugin_options['default_image']  ?
                esc_url( $this->my_plugin_options['default_image'] ) :
                self::RELATED_POSTS_DEFAULT_IMAGE
            );
    }

    private function setImgHtml( $img_url )
    {
        $img_url = $this->setImgUrl( $img_url );

        $img_additional_classes = [];
        $img_additional_classes[] = ((bool)$this->my_plugin_options['effect_of_increasing_the_image_size'] === true) ? 'increase' : '';

        return '<div class="spai-related_post_img ' . implode(' ', $img_additional_classes) . '" style="background-image: url(' . $img_url . ')"></div>';
    }

    private function sendImpression( $related_posts )
    {

	    if ( !empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
		    $ip = $_SERVER['HTTP_CLIENT_IP'];
	    } elseif ( !empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
		    $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	    } else {
		    $ip = $_SERVER['REMOTE_ADDR'];
	    }

	    $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $api = new Spai_Api( $this->token );
        $data = [
            'post_id' => $this->post_id,
            'recommended_posts' => $related_posts,
	        'ip' => $ip,
	        'user_agent' => $user_agent
        ];
        $answer = $api->sendImpressionData( $data );
        $json =  json_decode( json_decode( $answer['body'] ) );
        return $json;
    }

    private function prepareDataToWidget($relatedPosts, $ads)
    {
        $result = [];
        $adsCount = count($ads);
        $countAllElements = $adsCount + count($relatedPosts);

        if ($countAllElements > $this->count_posts) {
            $iMax = $this->count_posts;
        } else {
            $iMax = $countAllElements;
        }

        for ($i = 1; $i <= $iMax; $i++) {
            if ($i === 2 and $adsCount > 0 and !empty(array_values($ads)[0])) {
                $adsCurrent = array_values($ads)[0];
                $currentElement = [
                    'type' => 'ads',
                    'url' => $adsCurrent->link,
                    'img' => $adsCurrent->image,
                    'title' => $adsCurrent->title
                ];
            } elseif ($i === 4 and $adsCount > 0 and !empty(array_values($ads)[1])) {
                $adsCurrent = array_values($ads)[1];
                $currentElement = [
                    'type' => 'ads',
                    'url' => $adsCurrent->link,
                    'img' => $adsCurrent->image,
                    'title' => $adsCurrent->title
                ];
            } else {
                $postCurrent = array_shift($relatedPosts);
                $currentElement = [
                    'type' => 'post',
                    'url' => $postCurrent->post_url,
                    'img' => $postCurrent->img_url,
                    'title' => $postCurrent->title,
                    'external_id' => $postCurrent->external_id,
                    'categories' =>  $postCurrent->categories
                ];
            }
            $result[] = (object)$currentElement;
        }
        //echo '<pre>';var_dump($result);echo '</pre>';
        return $result;
    }

    private function setCountPosts()
    {
        $display_type = (int)$this->my_plugin_options['display_type'];

        $this->count_posts =
            ( in_array( $display_type, array(1, 5) ) ) ? 6 : (
            ( $display_type == 2 ) ? 4 : (
            ( $display_type == 3 ) ? 3 : (
            ( $display_type == 4 ) ? 8 : 6 ) ) );
    }

    private function setMaxAdsCount()
    {
        $display_type = (int)$this->my_plugin_options['display_type'];

        $this->max_ads_count =
            ( in_array( $display_type, array(1, 5) ) ) ? 2 : (
            ( $display_type == 2 ) ? 1 : (
            ( $display_type == 3 ) ? 1 : (
            ( $display_type == 4 ) ? 3 : 2 ) ) );
    }

    private function setAdsNotifierHtml()
    {
        $html = '<div class="spai-ads-notifier">';
            $html .= '<a class="spai-ads-notifier-block">Реклама</a>';
        $html .= '</div>';
        return $html;
    }
}
